==> cdk_2.7.1.orig.tar.gz: cdk-cdk-2.7.1/base/datadebug/src/test/java/org/openscience/cdk/debug/DebugMolecularFormulaTest.java <==
/* Copyright (C) 1997-2007  The Chemistry Development Kit (CDK) project
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */
package org.openscience.cdk.debug;

import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;
import org.openscience.cdk.test.interfaces.AbstractMolecularFormulaTest;
import org.openscience.cdk.interfaces.IMolecularFormula;

/**
 * Checks the functionality of the {@link DebugMolecularFormula}.
 *
 * @cdk.module test-datadebug
 */
public class DebugMolecularFormulaTest extends AbstractMolecularFormulaTest {

    @BeforeClass
    public static void setUp() {
        setBuilder(DebugChemObjectBuilder.getInstance());
    }

    @Test
    public void testDebugMolecularFormula() {
        IMolecularFormula mf = new DebugMolecularFormula();
        Assert.assertNotNull(mf);
    }
}

==> cdk_2.11.orig.tar.gz: cdk-cdk-2.11/base/datadebug/src/test/java/org/openscience/cdk/debug/DebugMolecularFormulaTest.java <==
/* Copyright (C) 1997-2007  The Chemistry Development Kit (CDK) project
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */
package org.openscience.cdk.debug;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;
import org.openscience.cdk.test.interfaces.AbstractMolecularFormulaTest;
import org.openscience.cdk.interfaces.IMolecularFormula;

/**
 * Checks the functionality of the {@link DebugMolecularFormula}.
 *
 */
class DebugMolecularFormulaTest extends AbstractMolecularFormulaTest {

    @BeforeAll
    static void setUp() {
        setBuilder(DebugChemObjectBuilder.getInstance());
    }

    @Test
    void testDebugMolecularFormula() {
        IMolecularFormula mf = new DebugMolecularFormula();
        Assertions.assertNotNull(mf);
    }
}
